[![Build Status](https://travis-ci.com/spotify/comet-core.svg?token=y6Hohk5x1wuwJMszK678&branch=master)](https://travis-ci.com/spotify/comet-core)

# Comet

Comet is an alert distribution framework which allows you to distribute alerts all the way to the resource owner with customizable owner lookup, de-duplication, alert formatting as well as automated follow up and metrics.

Built with ❤️ at Spotify

## Documentation
Please see the [Comet main repository](https://github.com/spotify/comet) for documentation.

## Code of Conduct

This project adheres to the [Open Code of Conduct][code-of-conduct]. By participating, you are expected to honor this code.

[code-of-conduct]: https://github.com/spotify/code-of-conduct/blob/master/code-of-conduct.md
